# shore

[![Build Status](https://drone.niklasrosenstein.com/api/badges/NiklasRosenstein/shore/status.svg)](https://drone.niklasrosenstein.com/NiklasRosenstein/shore)

Shore is an opinionated distribution and release management tool for pure
Python packages and mono repositories and is most effectively used with Git
repositories.

---

<p align="center">Copyright &copy; 2020, Niklas Rosenstein</p>
